Changelog
=========

<!--next-version-placeholder-->

## v0.7.2 (2023-02-10)
### Fix
* [560:robot:] Fix Packaging Issues ([`afd0075`](https://github.com/cowofevil/flask-ligand/commit/afd0075e67dd37b7d34048743d9a3d3bb6099641))

### Other
* [pre-commit.ci] auto fixes from pre-commit.com hooks ([`380e1bc`](https://github.com/cowofevil/flask-ligand/commit/380e1bc138200f18029f19fd5865c0e2e263f4ac))
* [pre-commit.ci] pre-commit autoupdate ([`c3204a1`](https://github.com/cowofevil/flask-ligand/commit/c3204a11945e9aa212b4bd84d5493a3c8355d7ad))
* [FIX] Update Deps ([`8267f7c`](https://github.com/cowofevil/flask-ligand/commit/8267f7c1e91fb0b21dc5296f5f3865223b20b311))

## v0.7.1 (2023-01-04)
### Fix
* [558:robot:] Fix Broken GitHub Actions Build Badge ([`ad779b9`](https://github.com/cowofevil/flask-ligand/commit/ad779b9f394604d422895976c37da89533d69573))

### Other
* :arrow_up: Update tox requirement from ~=3.27 to ~=4.1 ([`c4d0138`](https://github.com/cowofevil/flask-ligand/commit/c4d013836bfef63b78c8b26baba1c18bb32d82f5))
* :arrow_up: Update black requirement from ~=22.10 to ~=22.12 ([`4f2d522`](https://github.com/cowofevil/flask-ligand/commit/4f2d5228af40c748c48d3f75cc108430db00ef83))
* :arrow_up: Update types-setuptools requirement from ~=65.5 to ~=65.6 ([`4733343`](https://github.com/cowofevil/flask-ligand/commit/4733343d7e221304e7e43574014a192dcb18fe8b))
* :arrow_up: Update ipython requirement from ~=8.6 to ~=8.7 ([`188ca1a`](https://github.com/cowofevil/flask-ligand/commit/188ca1a878e1c4aac7f1d7a07cd1e56a493dd046))
* :arrow_up: Update flake8 requirement from ~=5.0 to ~=6.0 ([`0de75c5`](https://github.com/cowofevil/flask-ligand/commit/0de75c589e7c3d03d0dc7619aa8c3fbc67d87b01))
* [pre-commit.ci] pre-commit autoupdate ([`dd4ed81`](https://github.com/cowofevil/flask-ligand/commit/dd4ed81b65e0582b71e17a873b4bf1ff55de059a))
* :arrow_up: Update flask-migrate requirement from ~=3.1 to ~=4.0 ([`caf3f83`](https://github.com/cowofevil/flask-ligand/commit/caf3f832184b58bf3277a3937b06d79186ef5e9d))
* :arrow_up: Update mypy requirement from ~=0.990 to ~=0.991 ([`0e2b3ad`](https://github.com/cowofevil/flask-ligand/commit/0e2b3ad0cc5eb87f28e9edf9fe1b0f0665017d0c))
* [pre-commit.ci] pre-commit autoupdate ([`a7ae25e`](https://github.com/cowofevil/flask-ligand/commit/a7ae25e9e74fa6f94aa5fbf08ac028ab376ac230))
* [FIX] Update Quickstart Guide ([`68859bd`](https://github.com/cowofevil/flask-ligand/commit/68859bddef6a565a7602970899ec2b6dd9443827))

## v0.7.0 (2022-11-10)
### Feature
* [536:sparkles:] Generate OpenAPI Clients Offline ([`a341828`](https://github.com/cowofevil/flask-ligand/commit/a3418288ed8e7545dd3487ccd2e0729bc3b29dc8))

### Other
* :arrow_up: Update mypy requirement from ~=0.982 to ~=0.990 ([`ef885df`](https://github.com/cowofevil/flask-ligand/commit/ef885df4eb2073cf755b31ee5b40ed39677ccb8b))
* :arrow_up: Update tox requirement from ~=3.26 to ~=3.27 ([`b7d97dd`](https://github.com/cowofevil/flask-ligand/commit/b7d97ddb7856d321e206d7538fd2fa80a033f324))
* :arrow_up: Update sphinx-hoverxref requirement from ~=1.2 to ~=1.3 ([`512cde0`](https://github.com/cowofevil/flask-ligand/commit/512cde0947cc635625caf13fb7d7a410e95c1a5d))
* :arrow_up: Update ipython requirement from ~=8.5 to ~=8.6 ([`d28e4f4`](https://github.com/cowofevil/flask-ligand/commit/d28e4f411c08ee675c5ad6182d7691921f2f5b05))
* :arrow_up: Update pytest requirement from ~=7.1 to ~=7.2 ([`4905651`](https://github.com/cowofevil/flask-ligand/commit/4905651881bcada3a989bcce99c48c84df850714))
* :arrow_up: Update sphinx-hoverxref requirement from ~=1.1 to ~=1.2 ([`1012f9b`](https://github.com/cowofevil/flask-ligand/commit/1012f9b6b978bdc80e3a1dfcbdc5e60d23adb16e))
* :arrow_up: Update pyjwt requirement from ~=2.5 to ~=2.6 ([`e25975f`](https://github.com/cowofevil/flask-ligand/commit/e25975fb111c742186ea48d2291bae16aeeb0103))
* [545] Update to Python 3.11 Final ([`9f88e58`](https://github.com/cowofevil/flask-ligand/commit/9f88e58c52068104a15d8898bf359a760efd8988))
* [542] Drop Pre-Commit Tox Environment ([`a1315fa`](https://github.com/cowofevil/flask-ligand/commit/a1315fad93782bdfff8b0c38c93f95233ca4fb03))
* :arrow_up: Update sphinx requirement from ~=5.2 to ~=5.3 ([`ed6ff7c`](https://github.com/cowofevil/flask-ligand/commit/ed6ff7cf4b64590206598ba27794ad4905f24af5))
* :arrow_up: Update types-setuptools requirement from ~=65.4 to ~=65.5 ([`0e89bd9`](https://github.com/cowofevil/flask-ligand/commit/0e89bd9c8ae3561fa776f530754f4efda22b3c0e))

## v0.6.3 (2022-10-18)
### Fix
* [543:robot:] Refactor for flask-smorest Etag Changes ([`97ec979`](https://github.com/cowofevil/flask-ligand/commit/97ec9792ded9d81af1e84532e5b606e58b9b36ea))

## v0.6.2 (2022-10-17)
### Fix
* [543:robot:] Fix the Docs ([`b14184a`](https://github.com/cowofevil/flask-ligand/commit/b14184ad60c2e240d9a597fee6b49ef9a070127e))

## v0.6.1 (2022-10-17)
### Fix
* [543:robot:] Update Dependencies ([`7d27c5d`](https://github.com/cowofevil/flask-ligand/commit/7d27c5d67cd77a1610da7bd36c2cdccf3464b3fb))

### Other
* [pre-commit.ci] pre-commit autoupdate ([`36935af`](https://github.com/cowofevil/flask-ligand/commit/36935af517fa78557c4c899fa9701b4b828d9cbe))
* :arrow_up: Update black requirement from ~=22.8 to ~=22.10 ([`b8e8692`](https://github.com/cowofevil/flask-ligand/commit/b8e869281febfd2fd03deddb27dbaf295f66d32f))
* :arrow_up: Update flask-ligand-example requirement from ~=0.2 to ~=0.4 ([`7b032a2`](https://github.com/cowofevil/flask-ligand/commit/7b032a28932799119a997a454823720d76d2527c))
* [FIX] Fix Integration Test Suite Setup ([`908b20a`](https://github.com/cowofevil/flask-ligand/commit/908b20a5f07c4197743f446d1539d1605ebc1191))

## v0.6.0 (2022-10-07)
### Feature
* [511:sparkles:] Fix OIDC IAM Provider Configuration ([`9a885c0`](https://github.com/cowofevil/flask-ligand/commit/9a885c0717014825320a1b85b4bee9614f5ad742))

### Other
* :arrow_up: Update types-setuptools requirement from ~=65.3 to ~=65.4 ([`f6384b2`](https://github.com/cowofevil/flask-ligand/commit/f6384b26a2a1e23a1987d21905bddd02e853297e))
* :arrow_up: Update coverage[toml] requirement from ~=6.4 to ~=6.5 ([`da2f475`](https://github.com/cowofevil/flask-ligand/commit/da2f4753944ce4d6f77b6b78efe61394075e45b3))
* :arrow_up: Update pytest-mock requirement from ~=3.8 to ~=3.10 ([`59bb112`](https://github.com/cowofevil/flask-ligand/commit/59bb112f1d2ac0f983aa48f61dc5ca5af26ebefc))
* :arrow_up: Update pytest-cov requirement from ~=3.0 to ~=4.0 ([`b0c162d`](https://github.com/cowofevil/flask-ligand/commit/b0c162d064617b7ec244ae3b3587105d7179fd27))
* :arrow_up: Update mypy requirement from ~=0.971 to ~=0.982 ([`1bbd25f`](https://github.com/cowofevil/flask-ligand/commit/1bbd25f2d950e444160d0b0b84c044744a70fefa))
* :arrow_up: Update sphinx requirement from ~=5.1 to ~=5.2 ([`7e1b11e`](https://github.com/cowofevil/flask-ligand/commit/7e1b11e5e34fb33abb0353cee73fb1b371f653a3))
* [pre-commit.ci] pre-commit autoupdate ([`1b470b7`](https://github.com/cowofevil/flask-ligand/commit/1b470b7c465ec09769877a41185a55328f00427c))

## v0.5.0 (2022-10-06)
### Feature
* [500:sparkles:] Add Auth0 Support ([`0b5af21`](https://github.com/cowofevil/flask-ligand/commit/0b5af21985f5a890151e96d14d234cab8113b0b1))

### Other
* :arrow_up: Update tox requirement from ~=3.25 to ~=3.26 ([`0d025ea`](https://github.com/cowofevil/flask-ligand/commit/0d025ea50cc5b1eec790745c365bae38a0c25be1))
* :arrow_up: Update ipython requirement from ~=8.4 to ~=8.5 ([`4c98ed4`](https://github.com/cowofevil/flask-ligand/commit/4c98ed4a92dbd52da4cfee04173ca4b89e969898))
* :arrow_up: Update pipdeptree requirement from ~=2.2 to ~=2.3 ([`e4001b3`](https://github.com/cowofevil/flask-ligand/commit/e4001b31d208ca8b012f5c608e28b2eb4d5a1e3c))
* :arrow_up: Update pyjwt requirement from ~=2.4 to ~=2.5 ([`2a53e7d`](https://github.com/cowofevil/flask-ligand/commit/2a53e7db2dcbc98634b7edaae6b9d319d2b39863))

## v0.4.1 (2022-09-21)
### :robot:
* [541:robot:] Finish Quickstart Guide ([`bdf76bd`](https://github.com/cowofevil/flask-ligand/commit/bdf76bdb5843a3027dc7cbf9c547fc07f84c2554))

## v0.4.0 (2022-09-20)
### :sparkles:
* [538:sparkles:] Update Docs with Quickstart Guide ([`d99fed6`](https://github.com/cowofevil/flask-ligand/commit/d99fed65e10316cd24a986a47714523c40e4e72d))

## v0.3.4 (2022-09-13)
### :robot:
* [FIX:robot:] Add Missing Type Definition Marker ([`a84dfd6`](https://github.com/cowofevil/flask-ligand/commit/a84dfd6e39e4fcdfd99b8cfd7ef40293f745fa2e))

## v0.3.3 (2022-09-12)
### :robot:
* [FIX:robot:] Add the Missing Error Schema Fields ([`a4366e9`](https://github.com/cowofevil/flask-ligand/commit/a4366e9df0badebd1cf050390a1eb69ea3798fcb))

## v0.3.2 (2022-09-10)
### :robot:
* [FIX:robot:] Change Type Definition for BEARER_AUTH ([`1c10a1b`](https://github.com/cowofevil/flask-ligand/commit/1c10a1b7349cce80b72252fbed67f864c426c38b))

### Other
* :arrow_up: Update black requirement from ~=22.6 to ~=22.8 ([`38c5e43`](https://github.com/cowofevil/flask-ligand/commit/38c5e4355d42c12909314e7f4145e6d0bb40107b))
* :arrow_up: Update types-setuptools requirement from ~=65.1 to ~=65.3 ([`e34790b`](https://github.com/cowofevil/flask-ligand/commit/e34790ba04c1f77e40c239b1c40cd84d0603cf0d))
* :arrow_up: Update python-dotenv requirement from ~=0.20 to ~=0.21 ([`1de2b4d`](https://github.com/cowofevil/flask-ligand/commit/1de2b4d7ca85dfba0231c0692c4b3537f2011e47))

## v0.3.1 (2022-09-08)
### :robot:
* [FIX:robot:] Add Note about Building RTD Correctly ([`e27d050`](https://github.com/cowofevil/flask-ligand/commit/e27d050e9888353e8aa7635eff59c58237c4f176))

### Other
* [501] Add readthedocs Documentation ([`a907fdc`](https://github.com/cowofevil/flask-ligand/commit/a907fdcbc28e1bcf60b71500679f3c6c8044af5c))
* [FIX] Add Migrations Directory for Integration Tests ([`3310971`](https://github.com/cowofevil/flask-ligand/commit/3310971baa7574a28f35fd9af60d17d8bb8369ad))
* [CHORE] Increase Code Coverage Accuracy ([`3597db7`](https://github.com/cowofevil/flask-ligand/commit/3597db7f932ef2c93f3d263e1df557d52d9097aa))

## v0.3.0 (2022-08-30)
### :sparkles:
* [516:sparkles:] Support Database Migrations ([`b8c062b`](https://github.com/cowofevil/flask-ligand/commit/b8c062b925ea6f83c083a90398e5ee41ca03344e))

## v0.2.0 (2022-08-27)
### :sparkles:
* [510:sparkles:] Configurable Roles for RBAC Verification ([`d8e80a4`](https://github.com/cowofevil/flask-ligand/commit/d8e80a428875958a9af7e6774c8cfa2a370dab94))

### Other
* :arrow_up: Update types-setuptools requirement from ~=63.4 to ~=65.1 ([`7c8ef3a`](https://github.com/cowofevil/flask-ligand/commit/7c8ef3a6f19bf1f752d25f92ced9f22c67a24986))

## v0.1.3 (2022-08-25)
### :robot:
* [507:robot:] Configure Database Provider and URI ([`7e3d0c7`](https://github.com/cowofevil/flask-ligand/commit/7e3d0c7e1ce231893be80b6fd78802f0f589c347))

### Other
* [FIX] Enable SQLite Memory Database URI for Local Environment ([`fd5de8a`](https://github.com/cowofevil/flask-ligand/commit/fd5de8a4e7ad60368caa4e5c4604a944ab54c3dd))

## v0.1.2 (2022-08-18)
### :robot:
* [504:robot:] Fix Configuration Setting Issue and Update Docs ([`c3aea6c`](https://github.com/cowofevil/flask-ligand/commit/c3aea6c9f40b9f1bd2dd3da96f551733985c0332))

### Other
* [CHORE] Merge Coverage and Mypy Configuration into Pyproject ([`c187bf4`](https://github.com/cowofevil/flask-ligand/commit/c187bf42dea9b6316dee5a49eed2e9473e2f39c3))

## v0.1.1 (2022-08-18)
### :robot:
* [FIX:robot:] Update Flask and Fix Type Checking ([`7dbc587`](https://github.com/cowofevil/flask-ligand/commit/7dbc587d71bee3b111dc03ff539222959cbce426))

### Other
* :arrow_up: Update flask-smorest requirement from ~=0.38 to ~=0.39 ([`77d3679`](https://github.com/cowofevil/flask-ligand/commit/77d3679b1671a8ad3d405ded3a9c86e8c6713b32))
* :arrow_up: Update pygments requirement from ~=2.12 to ~=2.13 ([`1d75cd5`](https://github.com/cowofevil/flask-ligand/commit/1d75cd5e8b752a1f0c3dbffc67c07baa7f3c693b))
* :arrow_up: Update sqlalchemy-utils requirement from ~=0.32 to ~=0.38 ([`475ac06`](https://github.com/cowofevil/flask-ligand/commit/475ac0671becde3392d063c9045779bfed3c3fb8))

## v0.1.0 (2022-08-17)
### :sparkles:
* [473:sparkles:] Sanitize Codebase and Rename Everything to 'flask-ligand' ([`730dc0c`](https://github.com/cowofevil/flask-ligand/commit/730dc0c2825a8f0c40fee141e2001c46ec924700))

### Other
* Initial commit ([`7893f0d`](https://github.com/cowofevil/flask-ligand/commit/7893f0de70b26a853ad86a243d16b2d5589ba968))
